@@ -3,6 +3,7 @@ import os
 import subprocess
 import sys
 import json
+import logging
 from vyomcloudbridge.constants.constants import (
     vyom_variables_file,
 )
@@ -367,6 +368,19 @@ def main():
         action="store_true",
         help="Mark if the service is started by the system",
     )
+    # Verbose/debug flags (standard Linux pattern)
+    start_parser.add_argument(
+        "-v",
+        "--verbose",
+        action="count",
+        default=0,
+        help="Enable verbose/debug mode: -v or --verbose sets DEBUG level logging",
+    )
+    start_parser.add_argument(
+        "--debug",
+        action="store_true",
+        help="Enable debug mode (equivalent to -v, sets logging to DEBUG level)",
+    )
 
     # Service-specific arguments
     service_parsers = {
@@ -569,6 +583,15 @@ def main():
     # Handle starting a service with proper argument validation
     if args.action == "start":
         service_args = {}
+        debug_flags = {}  # Track flags separately for command display only
+        if args.debug or args.verbose >= 1:
+            log_level = logging.DEBUG
+            service_args["log_level"] = log_level
+            # Track which flag was used for command display (for service_manager only)
+            if args.debug:
+                debug_flags["_debug_flag"] = True
+            else:
+                debug_flags["_verbose_count"] = args.verbose
 
         if args.service == "queueworker":
             service_args["multi_thread"] = args.multi_thread
@@ -618,6 +641,7 @@ def main():
             service_class,
             name=args.name,
             system_default=args.system_default,
+            debug_flags=debug_flags,  # For command display only
             **service_args,
         )
 
