@@ -1,6 +1,7 @@
 # vyomcloudbridge/listeners/awsiot_mqtt_listener.py
 import base64
 import json
+import logging
 import os
 import threading
 import time
@@ -25,14 +26,12 @@ from vyomcloudbridge.constants.constants import (
     MQTT_ENTPOINT,
 )
 
-# logger = setup_logger(name=__name__, show_terminal=False)
-
 
 class AwsiotMqttListener(AbcListener):
-    def __init__(self, daemon: bool = False):
+    def __init__(self, daemon: bool = False, log_level=None):
         try:
             super().__init__(
-                multi_thread=False, daemon=daemon
+                multi_thread=False, daemon=daemon, log_level=log_level
             )  # TODO: we can remove multi_thread later
             self.logger.info("AwsiotMqttListener initializing...")
             # compulsory
@@ -129,7 +128,7 @@ class AwsiotMqttListener(AbcListener):
 
                     except Exception as e:
                         self.logger.debug(
-                            f"Warning: AWS IoT core connection attempt {attempt + 1} failed: {str(e)}"
+                            f"Warning: aws_mqtt_listener connection attempt {attempt + 1} failed: {str(e)}"
                         )
                         if attempt < self.max_reconnect_attempts - 1:
                             time.sleep(delay)
@@ -173,7 +172,9 @@ class AwsiotMqttListener(AbcListener):
                         self._create_mqtt_connection()
                     time.sleep(self.connection_health_check_delay)
                 except Exception as e:
-                    self.logger.error(f"Connection monitoring failed: {str(e)}")
+                    self.logger.error(
+                        f"aws_mqtt_listener connection monitoring failed: {str(e)}"
+                    )
                     time.sleep(self.connection_health_check_delay)
 
         # Start monitoring in a daemon thread
@@ -352,7 +353,6 @@ class AwsiotMqttListener(AbcListener):
         super().cleanup()
 
 
-
 def main():
     """
     Main entry point for the queue worker service.
