@@ -28,10 +28,10 @@ class MavListener(AbcListener):
         print("MavListener client service started")
         return cls._instance
 
-    def __init__(self, daemon: bool = False):
+    def __init__(self, daemon: bool = False, log_level=None):
         try:
             super().__init__(
-                multi_thread=False, daemon=False
+                multi_thread=False, daemon=False, log_level=log_level
             )  # TODO: we can remove multi_thread, daemon later
             self.logger.info("MavListener initializing...")
 
@@ -42,7 +42,7 @@ class MavListener(AbcListener):
             self.machine_id = self.machine_config.get("machine_id", "-") or "-"
 
             # shared memory
-            self.shared_mem = SharedMemoryUtil()
+            self.shared_mem = SharedMemoryUtil(log_level=log_level)
 
             self.mission_id = 0
             self.user_id = 1
@@ -168,7 +168,9 @@ class MavListener(AbcListener):
                     time.sleep(self.conn_health_check_delay)
                 except Exception as e:
                     self.is_connected = False
-                    self.logger.error(f"Connection monitoring failed: {str(e)}")
+                    self.logger.error(
+                        f"mav_listener connection monitoring failed: {str(e)}"
+                    )
                     time.sleep(self.conn_health_check_delay)
 
         # Start monitoring in a daemon thread
