@@ -1,9 +1,11 @@
+import logging
 import time
 import threading
 import os
 import json
 import base64
 import uuid
+import random
 from typing import Callable
 from awscrt import mqtt
 from awsiot import mqtt_connection_builder
@@ -20,10 +22,18 @@ from vyomcloudbridge.utils.abc_sender import AbcSender
 
 
 class AwsiotMqttSender(AbcSender):
-    def __init__(self, daemon: bool = False):
+    def __init__(self, daemon: bool = False, log_level=None):
         try:
-            super().__init__()
-            self.logger.info("AwsiotMqttSender initializing...")
+            super().__init__(log_level=log_level)
+            self.init_delay_sleep = 30
+            random_delay_sleep = random.uniform(
+                0,
+                self.init_delay_sleep,
+            )
+            self.logger.info(
+                f"AwsiotMqttSender initializing... with sleep {random_delay_sleep} seconds"
+            )
+            time.sleep(random_delay_sleep)
             # compulsory
             self.channel = "mqtt"
             self.combine_by_target_id = True
@@ -50,12 +60,17 @@ class AwsiotMqttSender(AbcSender):
 
             # Connection and reconnection parameters
             self.max_reconnect_attempts = 3
-            self.base_reconnect_delay = 2  # Base delay in seconds
-            self.max_reconnect_delay = 60
+            self.base_reconnect_delay = 20  # Base delay in seconds
+            self.exponential_base = 3
+            self.max_reconnect_delay = 120
 
-            self.connection_retry_loop_delay = 30  # seconds
+            self.connection_retry_loop_delay_min = 60  # seconds
+            self.connection_retry_loop_delay_max = 120  # seconds
+
+            self.early_exit_delay = 1  # seconds, to prevent infinite retry
 
             # Initialize the MQTT connection
+
             self.mqtt_connection = None
             if self.daemon:
                 # self._start_background_connection()
@@ -88,7 +103,8 @@ class AwsiotMqttSender(AbcSender):
                     try:
                         # Use exponential backoff for reconnection attempts
                         delay = min(
-                            self.base_reconnect_delay * (2**attempt),
+                            self.base_reconnect_delay
+                            * (self.exponential_base**attempt),
                             self.max_reconnect_delay,
                         )
 
@@ -115,7 +131,7 @@ class AwsiotMqttSender(AbcSender):
 
                     except Exception as e:
                         self.logger.debug(
-                            f"Warning: AWS IoT core connection attempt {attempt + 1} failed, error: {str(e)}"
+                            f"Warning: awsmqtt_sender connection attempt {attempt + 1} failed, error: {str(e)}, sleeping for {delay} sec..."
                         )
                         if attempt < self.max_reconnect_attempts - 1:
                             time.sleep(delay)
@@ -155,12 +171,25 @@ class AwsiotMqttSender(AbcSender):
         def monitor_connection():
             while True:
                 try:
+                    self.logger.debug(
+                        f"awsmqtt_sender monitor_connection loop running..., is_connected={self.is_connected}"
+                    )
                     if not self.is_connected:
                         self._create_mqtt_connection()
-                    time.sleep(self.connection_retry_loop_delay)
+                    delay_sleep = random.uniform(
+                        self.connection_retry_loop_delay_min,
+                        self.connection_retry_loop_delay_max,
+                    )
+                    time.sleep(delay_sleep)
                 except Exception as e:
-                    self.logger.error(f"Connection monitoring failed, error: {str(e)}")
-                    time.sleep(self.connection_retry_loop_delay)
+                    self.logger.error(
+                        f"awsmqtt_sender connection monitoring failed, error: {str(e)}"
+                    )
+                    delay_sleep = random.uniform(
+                        self.connection_retry_loop_delay_min,
+                        self.connection_retry_loop_delay_max,
+                    )
+                    time.sleep(delay_sleep)
 
         # Start monitoring in a daemon thread
         monitor_thread = threading.Thread(target=monitor_connection, daemon=True)
@@ -214,6 +243,7 @@ class AwsiotMqttSender(AbcSender):
                 self.logger.error(
                     "Topic length exceeded - a maximum of 8 sub-parts are allowed in a topic."
                 )
+                time.sleep(self.early_exit_delay)
                 return False
 
             # Outside the lock, create connection if needed
@@ -221,6 +251,7 @@ class AwsiotMqttSender(AbcSender):
                 self.logger.debug(
                     "Warning: MQTT connection not established, skipping publishing..."
                 )
+                time.sleep(self.early_exit_delay)
                 return False
             self.logger.debug(f"Message publishing...... to topic: {topic}")
             publish_future, _ = self.mqtt_connection.publish(
@@ -318,9 +349,6 @@ class AwsiotMqttSender(AbcSender):
             self.logger.error(f"Failed to close MQTT connection error: {str(e)}")
 
 
-logger = setup_logger(name=__name__, show_terminal=True)
-
-
 def main():
     try:
         # Initialize AwsiotMqttSender
@@ -341,15 +369,15 @@ def main():
         )
 
         if result:
-            logger.info("Message sent successfully")
+            print("Message sent successfully")
         else:
-            logger.error("Failed to send message")
+            print("Error: Failed to send message")
 
         # Close the connection when done
         sender.cleanup()
 
     except Exception as e:
-        logger.error(f"Error in minimal_mqtt_sender_example error: {str(e)}")
+        print(f"Error in minimal_mqtt_sender_example error: {str(e)}")
 
 
 if __name__ == "__main__":
