@@ -36,7 +36,7 @@ from vyomcloudbridge.constants.constants import (
 )
 
 
-logger = setup_logger(name=__name__, show_terminal=False)
+logger = setup_logger(name=__name__, show_terminal=False, log_level=logging.INFO)
 T = TypeVar("T", bound=ServiceAbstract)
 
 
@@ -120,6 +120,7 @@ class ServiceManager:
         service_class: Type[ServiceAbstract],
         name: Optional[str] = None,
         system_default: bool = False,
+        debug_flags: Optional[Dict] = None,
         *args,
         **kwargs,
     ):
@@ -129,7 +130,9 @@ class ServiceManager:
             service_name: The type of service to start
             service_class: The class that implements the service
             name: Optional custom instance name (if None, a random name will be generated)
-            *args, **kwargs: Arguments to pass to the service constructor
+            system_default: Whether this is a system default service
+            debug_flags: Internal flags for command display (_debug_flag, _verbose_count)
+            *args, **kwargs: Arguments to pass to the service constructor (log_level, multi_thread, etc.)
         """
         try:
             # Generate instance ID and instance name
@@ -141,6 +144,11 @@ class ServiceManager:
             while instance_name in existing_names:
                 instance_name = self.generate_container_name()
 
+            # Merge debug_flags into kwargs for command display
+            display_kwargs = dict(kwargs)
+            if debug_flags:
+                display_kwargs.update(debug_flags)
+
             pid = os.fork() if hasattr(os, "fork") else None
             # print("PIDDDDDDD-", pid)
             # Create the service instance
@@ -164,7 +172,7 @@ class ServiceManager:
                     "service_name": service_name,
                     "name": instance_name,
                     "command": self._format_command(
-                        service_name, name, system_default, kwargs
+                        service_name, name, system_default, display_kwargs
                     ),
                     "args": args,
                     "kwargs": kwargs,
@@ -216,6 +224,17 @@ class ServiceManager:
             command += f" --name {name}"
         if system_default:
             command += " --system-default"
+
+        # Standard Linux pattern: -v or --debug both mean DEBUG level
+        if kwargs.get("_debug_flag"):
+            command += " --debug"
+        elif kwargs.get("_verbose_count", 0) >= 1:
+            # Show -v for single, -vv for double (both set DEBUG)
+            if kwargs.get("_verbose_count", 0) >= 2:
+                command += " -vv"
+            else:
+                command += " -v"
+
         return command
 
     def stop_service(self, identifier: str) -> bool:
