@@ -24,8 +24,6 @@ from vyomcloudbridge.utils.common import (
 from vyomcloudbridge.constants.constants import data_buffer_key
 import traceback
 
-# logger = setup_logger(name=__name__, show_terminal=False)
-
 
 class DirWatcher:
     REQUIRED_KEYS = {"mission_id", "message_type", "priority"}
@@ -41,6 +39,7 @@ class DirWatcher:
         merge_chunks: bool = False,
         priority: int = 1,
         preserve_file: bool = False,  # this we will implement, move it to <dir>_preserve
+        log_level=None,
     ):
         """
         Initialize the DirWatcher with the specified watch directory.
@@ -53,9 +52,11 @@ class DirWatcher:
         #     raise ValueError(f"Missing required keys in properties: {missing_keys}")
 
         try:
+            self.log_level = log_level
             self.logger = setup_logger(
                 name=self.__class__.__module__ + "." + self.__class__.__name__,
                 show_terminal=False,
+                log_level=log_level,
             )
             self.watch_dir = Path(dir)
             self.is_mission_dir: bool = parse_bool(mission_dir)
@@ -408,7 +409,7 @@ class DirWatcher:
         try:
             try:
                 self.logger.info("Initializing QueueWriterFile client...")
-                self.queue_writer_client = QueueWriterFile()
+                self.queue_writer_client = QueueWriterFile(log_level=self.log_level)
                 self.is_running = True
                 self.logger.info("QueueWriterFile client initialized successfully")
             except Exception as e:
