@@ -25,11 +25,11 @@ class MachineStats(ServiceAbstract):
     Stores the current buffer state in a dedicated queue and publishes stats to HQ.
     """
 
-    def __init__(self):
+    def __init__(self, log_level=None):
         """
         Initialize the machine stats service with RabbitMQ connection.
         """
-        super().__init__()
+        super().__init__(log_level=log_level)
         self.host: str = "localhost"
         self.rabbitmq_url = DEFAULT_RABBITMQ_URL
         self.priority = 2  # live priority
@@ -41,15 +41,15 @@ class MachineStats(ServiceAbstract):
         self._connection_in_progress = False
         self.rmq_conn = None
         self.rmq_channel = None
-        self.rabbit_mq = RabbitMQ()
+        self.rabbit_mq = RabbitMQ(log_level=log_level)
         self.machine_config = Configs.get_machine_config()
         self.machine_id = self.machine_config.get("machine_id", "-") or "-"
         self.organization_id = self.machine_config.get("organization_id", "-") or "-"
         self.data_source = "machine_stats"
         self.buffer_update_lock = threading.Lock()
         self.expiration = "2000"  # milisecond
-        self.root_store = RootStore()
-        self.rabbit_mq_utils = RabbitMQUtils()
+        self.root_store = RootStore(log_level=log_level)
+        self.rabbit_mq_utils = RabbitMQUtils(log_level=log_level)
         self.rabbit_mq_api_sync_delay = 5  # seconds
         self.destination_ids = ["s3", "gcs_mqtt"]
         # Thread attributes
