@@ -20,9 +20,9 @@ from vyomcloudbridge.utils.configs import Configs
 
 
 class MavproxyHq(ServiceAbstract):
-    def __init__(self, daemon: bool = False):
-        super().__init__()
+    def __init__(self, daemon: bool = False, log_level=None):
         try:
+            super().__init__(log_level=log_level)
             # machine configs
             self.machine_config = Configs.get_machine_config()
             self.machine_id = self.machine_config.get("machine_id", "-") or "-"
@@ -296,7 +296,9 @@ class MavproxyHq(ServiceAbstract):
                     time.sleep(self.conn_health_check_delay)
                 except Exception as e:
                     self.is_connected = False
-                    self.logger.error(f"Connection monitoring failed: {str(e)}")
+                    self.logger.error(
+                        f"mavproxy_hq connection monitoring failed: {str(e)}"
+                    )
                     time.sleep(self.conn_health_check_delay)
 
         # Start monitoring in a daemon thread
