@@ -33,7 +33,7 @@ class MissionStats(ServiceAbstract):
     Also maintains current mission and current user data in dedicated queues.
     """
 
-    def __init__(self):
+    def __init__(self, log_level=None):
         """
         Initialize the mission data service with RabbitMQ connection.
 
@@ -41,7 +41,7 @@ class MissionStats(ServiceAbstract):
             rabbitmq_url: Connection URL for RabbitMQ
             logger: Optional logger instance
         """
-        super().__init__()
+        super().__init__(log_level=log_level)
         self.host: str = "localhost"
         self.rabbitmq_url = DEFAULT_RABBITMQ_URL
         self.mission_stats_publish_interval = 30
@@ -56,13 +56,13 @@ class MissionStats(ServiceAbstract):
 
         self.rmq_conn = None
         self.rmq_channel = None
-        self.rabbit_mq = RabbitMQ()
+        self.rabbit_mq = RabbitMQ(log_level=log_level)
         self.machine_config = Configs.get_machine_config()
         self.machine_id = self.machine_config.get("machine_id", "-") or "-"
         self.organization_id = self.machine_config.get("organization_id", "-") or "-"
         self.data_source_stats = "mission_stats"
 
-        self.machine_stats = MachineStats()
+        self.machine_stats = MachineStats(log_level=log_level)
         # Thread attributes
         self.data_listing_thread = None
         self.mission_thread = None
