@@ -1,3 +1,4 @@
+import logging
 from awscrt import io, mqtt
 from awsiot import mqtt_connection_builder
 import time
@@ -9,7 +10,7 @@ import json
 import threading
 
 log_dir = os.path.expanduser("/var/log/vyomcloudbridge")
-logger = setup_logger(log_dir, __name__, show_terminal=False)
+logger = setup_logger(log_dir, __name__, show_terminal=False, log_level=logging.INFO)
 
 
 def message_callback(topic, payload):
