@@ -17,15 +17,16 @@ from vyomcloudbridge.constants.constants import (
     MQTT_ENTPOINT,
 )
 
-logger = setup_logger(name=__name__, show_terminal=False)
 
 
 class MqttMachineClient:
     def __init__(
         self,
         message_callback: Optional[Callable] = None,
+        log_level=None,
     ):
         try:
+            self.logger = setup_logger(name=__name__, show_terminal=False, log_level=log_level)
             self.machine_config = Configs.get_machine_config()
             self.machine_id = self.machine_config.get("machine_id", "-") or "-"
             self.endpoint = MQTT_ENTPOINT
@@ -57,13 +58,13 @@ class MqttMachineClient:
             # Start a connection monitoring thread
             self._start_backgd_conn_monitor()
         except Exception as e:
-            logger.error(f"Error init MqttMachineClient: {str(e)}")
+            self.logger.error(f"Error init MqttMachineClient: {str(e)}")
             raise
 
     def _verify_cert_files(self):
         for file_path in [self.cert_path, self.pri_key_path, self.root_ca_path]:
             if not os.path.exists(file_path):
-                logger.error(f"ERROR: File not found: {file_path}")
+                self.logger.error(f"ERROR: File not found: {file_path}")
                 raise FileNotFoundError(f"Required file not found: {file_path}")
             else:
                 with open(file_path, "r") as f:
@@ -74,7 +75,7 @@ class MqttMachineClient:
         with self.connection_lock:  # Acquire lock to prevent concurrent attempts
             if self.is_connected:
                 self._connection_in_progress = False
-                logger.info("Connection already established, skipping reconnection")
+                self.logger.info("Connection already established, skipping reconnection")
                 return
 
             self._connection_in_progress = True
@@ -105,20 +106,20 @@ class MqttMachineClient:
                         connect_future = self.mqtt_connection.connect()
                         connect_future.result(timeout=10)  # Wait for connection
                         self.is_connected = True
-                        logger.info("Successfully connected to AWS IoT Core")
+                        self.logger.info("Successfully connected to AWS IoT Core")
 
                         self._resubscribe_to_topics()
                         return
 
                     except Exception as e:
-                        logger.error(
+                        self.logger.error(
                             f"AWS IoT core connection attempt {attempt + 1} failed: {str(e)}"
                         )
                         if attempt < self.max_reconnect_attempts - 1:
                             time.sleep(delay)
 
                 # If all attempts fail
-                logger.error(
+                self.logger.error(
                     "Failed to establish MQTT connection after multiple attempts"
                 )
                 raise ConnectionError("Could not connect to AWS IoT Core")
@@ -131,7 +132,7 @@ class MqttMachineClient:
         Callback when connection is interrupted
         This method is called automatically by AWS IoT SDK
         """
-        logger.warning(f"Connection interrupted: {error}")
+        self.logger.warning(f"Connection interrupted: {error}")
         with self.connection_lock:
             self.is_connected = False
 
@@ -143,7 +144,7 @@ class MqttMachineClient:
         This method is called automatically by AWS IoT SDK
         """
         if return_code == mqtt.ConnectReturnCode.ACCEPTED:
-            logger.info("Connection resumed successfully")
+            self.logger.info("Connection resumed successfully")
 
             with self.connection_lock:
                 self.is_connected = True
@@ -153,7 +154,7 @@ class MqttMachineClient:
                 self._resubscribe_to_topics()
  
         else:
-            logger.error(f"Connection resume failed with return code: {return_code}")
+            self.logger.error(f"Connection resume failed with return code: {return_code}")
 
     def _resubscribe_to_topics(self):
         """
@@ -167,9 +168,9 @@ class MqttMachineClient:
                     callback=self.message_callback,
                 )
                 subscribe_future.result(timeout=10)
-                logger.info(f"Resubscribed to topic: {topic}")
+                self.logger.info(f"Resubscribed to topic: {topic}")
             except Exception as e:
-                logger.error(f"Failed to resubscribe to {topic}: {str(e)}")
+                self.logger.error(f"Failed to resubscribe to {topic}: {str(e)}")
 
     def _start_backgd_conn_monitor(self):
         """
@@ -181,11 +182,11 @@ class MqttMachineClient:
             while True:
                 try:
                     if not self.is_connected:
-                        logger.warning("Connection is down. Attempting to reconnect...")
+                        self.logger.warning("Connection is down. Attempting to reconnect...")
                         self._create_mqtt_connection()
                     time.sleep(30)
                 except Exception as e:
-                    logger.error(f"Connection monitoring failed: {str(e)}")
+                    self.logger.error(f"Connection monitoring failed: {str(e)}")
 
         # Start monitoring in a daemon thread
         monitor_thread = threading.Thread(target=monitor_connection, daemon=True)
@@ -193,13 +194,13 @@ class MqttMachineClient:
 
     def message_callback(self, topic, payload, **kwargs):
         try:
-            logger.info(f"Received message from topic '{topic}': {json.loads(payload)}")
+            self.logger.info(f"Received message from topic '{topic}': {json.loads(payload)}")
             if self.message_callback:
                 self.message_callback(topic, payload)
             else:
-                logger.info("No callback provided, skipping callback execution")
+                self.logger.info("No callback provided, skipping callback execution")
         except Exception as e:
-            logger.error(f"Error in calling callback MqttMachineClient: {str(e)}")
+            self.logger.error(f"Error in calling callback MqttMachineClient: {str(e)}")
 
     def subscribe_to_topic(self, topic):
         """
@@ -209,14 +210,14 @@ class MqttMachineClient:
             is_connection_tried = self._connection_in_progress
             with self.connection_lock:
                 if not self.is_connected and is_connection_tried:
-                    logger.error(
+                    self.logger.error(
                         f"Subscription to {topic} failed:: aws iot core is not connected"
                     )
                     raise
 
             if not self.is_connected:
                 self.subscribed_topics.add(topic)
-                logger.debug(
+                self.logger.debug(
                     "Warning: MQTT connection not established, skipping for now, will get auto subscribed later..."
                 )
                 return
@@ -228,10 +229,10 @@ class MqttMachineClient:
 
             # Track subscribed topics
             self.subscribed_topics.add(topic)
-            logger.info(f"Subscribed to topic: {topic}")
+            self.logger.info(f"Subscribed to topic: {topic}")
 
         except Exception as e:
-            logger.error(f"Subscription to {topic} failed: {str(e)}")
+            self.logger.error(f"Subscription to {topic} failed: {str(e)}")
             raise
 
     def publish_message(self, topic: str, payload, retain: bool = False):
@@ -241,7 +242,7 @@ class MqttMachineClient:
         try:
             path_parts = topic.split("/")
             if len(path_parts) > 8:
-                logger.error(
+                self.logger.error(
                     "Topic length exceeded - a maximum of 8 sub-parts are allowed in a topic."
                 )
                 return False
@@ -249,7 +250,7 @@ class MqttMachineClient:
             is_connection_tried = self._connection_in_progress
             with self.connection_lock:
                 if not self.is_connected and is_connection_tried:
-                    logger.error(
+                    self.logger.error(
                         f"Publish to {topic} failed: aws iot core is not connected"
                     )
                     return False
@@ -257,19 +258,19 @@ class MqttMachineClient:
             # Outside the lock, create connection if needed
             if not self.is_connected:
                 self._create_mqtt_connection()
-            logger.info(f"mqtt data publishing...... to topic: {topic}")
+            self.logger.info(f"mqtt data publishing...... to topic: {topic}")
             publish_future, _ = self.mqtt_connection.publish(
                 topic=topic, payload=payload, qos=mqtt.QoS.AT_LEAST_ONCE, retain=retain
             )
             publish_future.result(timeout=10)
 
-            logger.info(f"mqtt data published to topic: {topic}")
+            self.logger.info(f"mqtt data published to topic: {topic}")
             return True
         except TimeoutError:
-            logger.error(f"Publish to {topic} failed: TimeoutError")
+            self.logger.error(f"Publish to {topic} failed: TimeoutError")
             return False
         except Exception as e:
-            logger.error(
+            self.logger.error(
                 f"Publish to {topic} failed: {str(e)} , message_type={type(payload)}"
             )
             return False
@@ -285,7 +286,7 @@ class MqttMachineClient:
             with self.connection_lock:
                 self.is_connected = False
 
-            logger.info("MQTT AWS IoT Core connection closed successfully")
+            self.logger.info("MQTT AWS IoT Core connection closed successfully")
 
         except Exception as e:
-            logger.error(f"Failed to close MQTT connection: {str(e)}")
+            self.logger.error(f"Failed to close MQTT connection: {str(e)}")
