@@ -433,7 +433,7 @@ def main():
         server_id = "hq"
 
         # Publish a test message
-        publish_topic_1 = f"vyom-mqtt-msg/{machine_id}/sample_source/34343434.json"
+        publish_topic_1 = f"vyom-mqtt-msg/{machine_id}/gcs/connect_message/34343434.json"
         message_connect = {
             "type": "CONNECT_DRONE",
             "data": {"droneId": machine_id, "timestamp": "number", "parameters": {}},
