@@ -34,11 +34,13 @@ class QueueWorker(ServiceAbstract):
         multi_thread: bool = False,
         host: str = "localhost",
         num_threads: int = UPLOAD_THREADS,
+        log_level=None,
     ):
         try:
-            super().__init__(multi_thread=multi_thread)
+            self.log_level = log_level
+            super().__init__(multi_thread=multi_thread, log_level=log_level)
             self.logger.info("QueueWorker initializing...")
-            self.mission_stats = MissionStats()
+            self.mission_stats = MissionStats(log_level=log_level)
             self.vyom_sender = None
             self.fail_client_pausetime = 3
             self.logger.info("QueueWorker initialized successfully!")
@@ -61,7 +63,7 @@ class QueueWorker(ServiceAbstract):
         max_retries = 3
         for attempt in range(max_retries):
             try:
-                vyom_sender = VyomSender()
+                vyom_sender = VyomSender(log_level=self.log_level)
                 return vyom_sender
             except Exception as e:
                 self.logger.error(f"Attempt {attempt + 1} failed: {e}")
@@ -394,6 +396,9 @@ class QueueWorker(ServiceAbstract):
             while self.is_running:
                 # Process messages for a short time before checking if we should stop
                 rmq_conn.process_data_events(time_limit=1)
+                # self.logger.debug(
+                #     "Processed pending RabbitMQ events in queue '%s'", self.queue_name
+                # )
 
         except (ConnectionClosedByBroker, AMQPChannelError) as e:
             self.logger.error(f"Connection error in worker: {e}")
@@ -451,17 +456,21 @@ class QueueWorker(ServiceAbstract):
             self.logger.info("Starting QueueWorker service...")
             self.is_running = True
 
-            def upload_publisher_loop():
+            def upload_stats_loop():
                 while self.is_running:
                     try:
                         self._publish_upload_stats()
                         time.sleep(self.upload_stats_publish_interval)
+                        self.logger.debug(
+                            "Upload stats published; sleeping for %s seconds",
+                            self.upload_stats_publish_interval,
+                        )
                     except Exception as e:
                         self.logger.error(f"Error in stats publisher loop: {str(e)}")
                         time.sleep(self.upload_stats_error_delay)
 
             self.data_listing_thread = threading.Thread(
-                target=upload_publisher_loop, daemon=True
+                target=upload_stats_loop, daemon=True
             )
             self.data_listing_thread.start()
 
@@ -469,6 +478,9 @@ class QueueWorker(ServiceAbstract):
             self.start_consume()
 
             while self.is_running:
+                self.logger.debug(
+                    "QueueWorker is actively running for queue '%s'", self.queue_name
+                )
                 time.sleep(10)
 
         except Exception as e:
