@@ -1,5 +1,6 @@
 # vyomcloudbridge/queue_writer.py
 from concurrent.futures import ThreadPoolExecutor
+import logging
 import time
 import random
 from datetime import datetime, timezone
@@ -35,7 +36,8 @@ from vyomcloudbridge.constants.constants import (
 class ThreadSafeRabbitMQPool:  # use this QueueWriter, instead of QueueWriterJson from queue_write.py
     """Thread-safe RabbitMQ connection pool with actual connection reuse"""
 
-    def __init__(self, max_pool_size: int = 8):
+    def __init__(self, max_pool_size: int = 8, log_level=None):
+        self.log_level = log_level
         self._thread_local = threading.local()
         self._pool_lock = threading.Lock()
         self._connection_pool = Queue(maxsize=max_pool_size)
@@ -46,6 +48,7 @@ class ThreadSafeRabbitMQPool:  # use this QueueWriter, instead of QueueWriterJso
         self.logger = setup_logger(
             name=self.__class__.__module__ + "." + self.__class__.__name__,
             show_terminal=False,
+            log_level=log_level,
         )
 
     def get_connection(self) -> RabbitMQ:
@@ -89,7 +92,7 @@ class ThreadSafeRabbitMQPool:  # use this QueueWriter, instead of QueueWriterJso
         if connection is None:
             with self._pool_lock:
                 if self._created_connections < self._max_pool_size:
-                    connection = RabbitMQ()
+                    connection = RabbitMQ(log_level=self.log_level)
                     self._created_connections += 1
                     self.logger.debug(
                         f"Created new RabbitMQ connection for thread {threading.current_thread().name} "
@@ -118,7 +121,7 @@ class ThreadSafeRabbitMQPool:  # use this QueueWriter, instead of QueueWriterJso
                     self.logger.warning(
                         "Creating connection despite limit due to timeout"
                     )
-                    connection = RabbitMQ()
+                    connection = RabbitMQ(log_level=self.log_level)
 
         # Register the connection as active for this thread
         with self._pool_lock:
@@ -214,10 +217,10 @@ class ThreadSafeRabbitMQPool:  # use this QueueWriter, instead of QueueWriterJso
 class QueueWriter:  # use this QueueWriter, instead of QueueWriterJson from queue_write.py
     """Main class for handling message queue writing operations."""
 
-    def __init__(self):
-        self.rabbit_mq = RabbitMQ()  # Main thread connection
-        self.rabbit_mq_pool = (
-            ThreadSafeRabbitMQPool()
+    def __init__(self, log_level=None):
+        self.rabbit_mq = RabbitMQ(log_level=log_level)  # Main thread connection
+        self.rabbit_mq_pool = ThreadSafeRabbitMQPool(
+            log_level=log_level
         )  # Thread pool for background threads
         self.machine_config = Configs.get_machine_config()
         self.machine_id = self.machine_config.get("machine_id", "-") or "-"
@@ -225,12 +228,13 @@ class QueueWriter:  # use this QueueWriter, instead of QueueWriterJson from queu
         self.logger = setup_logger(
             name=self.__class__.__module__ + "." + self.__class__.__name__,
             show_terminal=False,
+            log_level=log_level,
         )
-        self.chunk_merger = ChunkMerger()
+        self.chunk_merger = ChunkMerger(log_level=log_level)
         # self.mission_stats = MissionStats() # TODO: remove later
-        self.watching_live = True # if a watcher is available to watch live data
+        self.watching_live = True  # if a watcher is available to watch live data
         self.live_priority = 2
-        self.live_destinations = ["s3", "gcs_mqtt"] # TODO real time later
+        self.live_destinations = ["s3", "gcs_mqtt"]  # TODO real time later
         self.live_expiry_time = "2000"  # millisecond
         self.live_executor = ThreadPoolExecutor(
             max_workers=4, thread_name_prefix="live"
@@ -1043,15 +1047,15 @@ class QueueWriter:  # use this QueueWriter, instead of QueueWriterJson from queu
             pass
 
 
-logger = setup_logger(name=__name__, show_terminal=False)
-
-
 def main():
     # # Example 1, send data, without live
     from vyomcloudbridge.services.queue_writer import QueueWriter
+    import time
+
+    default_mission_id = "_all_"
 
     try:
-        writer = QueueWriter()
+        writer = QueueWriter(log_level=logging.INFO)
         message_data = {"lat": 75.66666, "long": 73.0589455, "alt": 930}
         data_source = "MACHINE_POSE"  # event, warning, camera1, camera2,
         data_type = "json"  # image, binary, json
