@@ -25,16 +25,13 @@ from vyomcloudbridge.constants.constants import (
 )
 
 
-# logger = setup_logger(name=__name__, show_terminal=False)
-
-
 class QueueWriterFile:
     """Main class for handling message queue writing operations."""
 
     # Mapping file extensions to data types
-    def __init__(self):
-        self.rabbit_mq = RabbitMQ()
-        self.live_destinations = ["s3", "gcs_mqtt"] # TODO real time later
+    def __init__(self, log_level=None):
+        self.rabbit_mq = RabbitMQ(log_level=log_level)
+        self.live_destinations = ["s3", "gcs_mqtt"]  # TODO real time later
         self.live_priority = 2
         self.live_expiry_time = "2000"  # milliseconds
         self.machine_config = Configs.get_machine_config()
@@ -43,8 +40,9 @@ class QueueWriterFile:
         self.logger = setup_logger(
             name=self.__class__.__module__ + "." + self.__class__.__name__,
             show_terminal=False,
+            log_level=log_level,
         )
-        self.chunk_merger = ChunkMerger()
+        self.chunk_merger = ChunkMerger(log_level=log_level)
         self._setup_signal_handlers()
 
     def _setup_signal_handlers(self):
@@ -235,8 +233,10 @@ class QueueWriterFile:
                         "is_chunked": False,
                     }
                 )
-                
-            if properties is not None or should_chunk: # send file properties only when required
+
+            if (
+                properties is not None or should_chunk
+            ):  # send file properties only when required
                 file_properties_topic = f"{file_dir}/file_properties/{filename}.json"
                 headers = {
                     "topic": file_properties_topic,
@@ -249,7 +249,9 @@ class QueueWriterFile:
                     "data_type": data_type,
                 }
                 self.rabbit_mq.enqueue_message(
-                    message=json.dumps(file_info_data), headers=headers, priority=priority
+                    message=json.dumps(file_info_data),
+                    headers=headers,
+                    priority=priority,
                 )
                 self.logger.info(
                     f"Data enqueued to {file_properties_topic}, with priority: {priority}"
@@ -326,7 +328,9 @@ class QueueWriterFile:
                         )
                         live_message = file_data
                         live_data_type = (
-                            "binary" if data_type not in ["image", "json"] else data_type
+                            "binary"
+                            if data_type not in ["image", "json"]
+                            else data_type
                         )
                         data_size = (
                             len(file_data)
