@@ -1,5 +1,6 @@
 # vyomcloudbridge/queue_writer_json.py
 from concurrent.futures import ThreadPoolExecutor
+import logging
 import time
 import random
 from datetime import datetime, timezone
@@ -32,10 +33,11 @@ from vyomcloudbridge.constants.constants import (
 )
 
 
-class ThreadSafeRabbitMQPool: # This is deprecated file, please use QueueWriter from queue_write.py
+class ThreadSafeRabbitMQPool:  # This is deprecated file, please use QueueWriter from queue_write.py
     """Thread-safe RabbitMQ connection pool with actual connection reuse"""
 
-    def __init__(self, max_pool_size: int = 8):
+    def __init__(self, max_pool_size: int = 8, log_level=None):
+        self.log_level = log_level
         self._thread_local = threading.local()
         self._pool_lock = threading.Lock()
         self._connection_pool = Queue(maxsize=max_pool_size)
@@ -46,6 +48,7 @@ class ThreadSafeRabbitMQPool: # This is deprecated file, please use QueueWriter
         self.logger = setup_logger(
             name=self.__class__.__module__ + "." + self.__class__.__name__,
             show_terminal=False,
+            log_level=log_level,
         )
 
     def get_connection(self) -> RabbitMQ:
@@ -89,7 +92,7 @@ class ThreadSafeRabbitMQPool: # This is deprecated file, please use QueueWriter
         if connection is None:
             with self._pool_lock:
                 if self._created_connections < self._max_pool_size:
-                    connection = RabbitMQ()
+                    connection = RabbitMQ(log_level=self.log_level)
                     self._created_connections += 1
                     self.logger.debug(
                         f"Created new RabbitMQ connection for thread {threading.current_thread().name} "
@@ -118,7 +121,7 @@ class ThreadSafeRabbitMQPool: # This is deprecated file, please use QueueWriter
                     self.logger.warning(
                         "Creating connection despite limit due to timeout"
                     )
-                    connection = RabbitMQ()
+                    connection = RabbitMQ(log_level=self.log_level)
 
         # Register the connection as active for this thread
         with self._pool_lock:
@@ -211,13 +214,13 @@ class ThreadSafeRabbitMQPool: # This is deprecated file, please use QueueWriter
             }
 
 
-class QueueWriterJson: # This is deprecated file, please use QueueWriter from queue_write.py
+class QueueWriterJson:  # This is deprecated file, please use QueueWriter from queue_write.py
     """Main class for handling message queue writing operations."""
 
-    def __init__(self):
-        self.rabbit_mq = RabbitMQ()  # Main thread connection
-        self.rabbit_mq_pool = (
-            ThreadSafeRabbitMQPool()
+    def __init__(self, log_level=None):
+        self.rabbit_mq = RabbitMQ(log_level=log_level)  # Main thread connection
+        self.rabbit_mq_pool = ThreadSafeRabbitMQPool(
+            log_level=log_level
         )  # Thread pool for background threads
         self.machine_config = Configs.get_machine_config()
         self.machine_id = self.machine_config.get("machine_id", "-") or "-"
@@ -225,12 +228,13 @@ class QueueWriterJson: # This is deprecated file, please use QueueWriter from qu
         self.logger = setup_logger(
             name=self.__class__.__module__ + "." + self.__class__.__name__,
             show_terminal=False,
+            log_level=log_level,
         )
-        self.chunk_merger = ChunkMerger()
+        self.chunk_merger = ChunkMerger(log_level=log_level)
         # self.mission_stats = MissionStats() # TODO: remove later
-        self.watching_live = True # if a watcher is available to watch live data
+        self.watching_live = True  # if a watcher is available to watch live data
         self.live_priority = 2
-        self.live_destinations = ["s3", "gcs_mqtt"] # TODO real time later
+        self.live_destinations = ["s3", "gcs_mqtt"]  # TODO real time later
         self.live_expiry_time = "2000"  # millisecond
         self.live_executor = ThreadPoolExecutor(
             max_workers=4, thread_name_prefix="live"
@@ -1043,9 +1047,6 @@ class QueueWriterJson: # This is deprecated file, please use QueueWriter from qu
             pass
 
 
-logger = setup_logger(name=__name__, show_terminal=False)
-
-
 def main():
     # # Example 1, send data, without live
     from vyomcloudbridge.services.queue_writer_json import QueueWriterJson
