@@ -14,17 +14,15 @@ import os
 from vyomcloudbridge.utils.logger_setup import setup_logger
 from vyomcloudbridge.constants.constants import main_data_queue
 
-logger = setup_logger(name=__name__, show_terminal=False)
-
-
 class RabbitMQ:
-    def __init__(self, host: str = "localhost", queue_name: str = main_data_queue):
+    def __init__(self, host: str = "localhost", queue_name: str = main_data_queue, log_level=None):
         self.host = host
         self.queue_name = queue_name
         self.rmq_conn = None
         self.rmq_channel = None
         self.is_consuming = False
         self.max_enqueue_retries = 5
+        self.logger = setup_logger(name=__name__, show_terminal=False, log_level=log_level)
         # Don't set up connection in __init__ when running as service
         # It will be set up in consume() instead
 
@@ -60,26 +58,26 @@ class RabbitMQ:
 
                 # Set QoS
                 self.rmq_channel.basic_qos(prefetch_count=1)
-                logger.debug("RabbitMQ connection established")
+                self.logger.debug("RabbitMQ connection established")
                 return
 
             except AMQPConnectionError as e:
                 if attempt == max_retries - 1:
-                    logger.error(
+                    self.logger.error(
                         f"Failed to connect to RabbitMQ after {max_retries} attempts"
                     )
                     raise
-                logger.warning(
+                self.logger.warning(
                     f"RabbitMQ connection attempt {attempt + 1} failed AMQPConnectionError, retrying..."
                 )
                 time.sleep(2**attempt)
             except Exception as e:
                 if attempt == max_retries - 1:
-                    logger.error(
+                    self.logger.error(
                         f"Failed to connect to RabbitMQ after {max_retries} attempts"
                     )
                     raise
-                logger.warning(
+                self.logger.warning(
                     f"RabbitMQ connection attempt {attempt + 1} failed, retrying..."
                 )
                 time.sleep(2**attempt)
@@ -92,7 +90,7 @@ class RabbitMQ:
                 return True
 
             if not self.rmq_channel or self.rmq_channel.is_closed:
-                logger.info("Closed channel found, re-establishing...")
+                self.logger.info("Closed channel found, re-establishing...")
                 self.rmq_channel = self.rmq_conn.channel()
                 # Declare queue with priority support
                 self.rmq_channel.queue_declare(
@@ -106,11 +104,11 @@ class RabbitMQ:
 
                 # Set QoS
                 self.rmq_channel.basic_qos(prefetch_count=1)
-                logger.info("Channel re-established successfully")
+                self.logger.info("Channel re-established successfully")
 
             return True
         except Exception as e:
-            logger.error(f"Failed to ensure connection: {e}")
+            self.logger.error(f"Failed to ensure connection: {e}")
             self.rmq_conn = None
             self.rmq_channel = None
             return False
@@ -137,9 +135,9 @@ class RabbitMQ:
                 properties=pika.BasicProperties(delivery_mode=2),
             )
         except Exception as e:
-            logger.error(f"Error publishing enqueue_message_size : {e}")
+            self.logger.error(f"Error publishing enqueue_message_size : {e}")
             if retry_count > self.max_enqueue_retries:
-                logger.error(
+                self.logger.error(
                     f"Failed to publish enqueue_message_size after {retry_count} retries, ignoring message"
                 )
                 return
@@ -196,17 +194,17 @@ class RabbitMQ:
             # )
 
             expiry_log = f" with expiration {expiration}ms" if expiration else ""
-            logger.debug(
+            self.logger.debug(
                 f"Enqueued message to queue {queue_name} with priority {priority}{expiry_log}"
             )
         except Exception as e:
             import traceback
 
-            logger.error(
+            self.logger.error(
                 f"Error publishing message: {e}\n{traceback.format_exc()}, headers={headers}"
             )
             if retry_count > self.max_enqueue_retries:
-                logger.error(
+                self.logger.error(
                     f"Failed to publish message after {retry_count} retries, ignoring message"
                 )
                 return
@@ -242,9 +240,9 @@ class RabbitMQ:
                 headers = properties.headers
             else:
                 channel.basic_ack(delivery_tag=method_frame.delivery_tag)
-                logger.error(f"Headers not found in messase skipping message")
+                self.logger.error(f"Headers not found in messase skipping message")
                 return
-            logger.debug(f"proccessing data having header={headers}")
+            self.logger.debug(f"proccessing data having header={headers}")
             queue_name = method_frame.routing_key
             priority = properties.priority if properties.priority is not None else 0
             new_priority = max(priority - 1, 0) if priority < 3 else priority  # TODO
@@ -252,7 +250,7 @@ class RabbitMQ:
             expiry_info = ""
             if hasattr(properties, "expiration") and properties.expiration:
                 expiry_info = f" with expiration {properties.expiration}ms"
-            logger.debug(
+            self.logger.debug(
                 f"Processing message from {queue_name} with priority {priority}{expiry_info}"
             )
             # pass data to callback in format
@@ -270,10 +268,10 @@ class RabbitMQ:
 
             if result:
                 channel.basic_ack(delivery_tag=method_frame.delivery_tag)
-                logger.debug(f"Message processed successfully in {queue_name}")
+                self.logger.debug(f"Message processed successfully in {queue_name}")
             else:
                 # If processing failed, republish with mew priority instead of just nacking
-                logger.warning(
+                self.logger.warning(
                     f"Message processing failed in {queue_name}, requeuing with new priority {new_priority}"
                 )
                 # First ack the original message
@@ -294,7 +292,7 @@ class RabbitMQ:
                     else:
                         # new_properties["expiration"] = "0"
                         # Above does not worked, as immediate consumer is available,
-                        logger.info(
+                        self.logger.info(
                             f"Message expiration time reached, marked as expired {queue_name}"
                         )
                         return
@@ -319,11 +317,11 @@ class RabbitMQ:
                 )
 
         except Exception as e:
-            logger.error(f"Error processing message in {queue_name}: {e}")
+            self.logger.error(f"Error processing message in {queue_name}: {e}")
             # For exceptions, also republish with new priority
             try:
                 priority = properties.priority if properties.priority is not None else 0
-                logger.warning(
+                self.logger.warning(
                     f"Error processing message, requeuing with new priority {new_priority}"
                 )
                 # First ack the original message
@@ -344,7 +342,7 @@ class RabbitMQ:
                     else:
                         # new_properties["expiration"] = "0"
                         # Above does not worked, as immediate consumer is available,
-                        logger.info(
+                        self.logger.info(
                             f"Message expiration time reached, marked as expired {queue_name}"
                         )
                         return
@@ -368,7 +366,7 @@ class RabbitMQ:
                     properties=pika.BasicProperties(**new_properties),
                 )
             except Exception as republish_error:
-                logger.error(
+                self.logger.error(
                     f"Failed to republish message with new priority: {republish_error}"
                 )
                 channel.basic_nack(delivery_tag=method_frame.delivery_tag, requeue=True)
@@ -379,14 +377,14 @@ class RabbitMQ:
         if not self._ensure_connection() or not self.rmq_channel:
             raise Exception("Could not establish initial connection")
 
-        logger.info(f"Started consuming messages from {self.queue_name}...")
+        self.logger.info(f"Started consuming messages from {self.queue_name}...")
 
         self.is_consuming = True
 
         while self.is_consuming:
             try:
                 if not self._ensure_connection() or not self.rmq_channel:
-                    logger.warning("Connection lost, waiting before retry...")
+                    self.logger.warning("Connection lost, waiting before retry...")
                     time.sleep(1)
                     continue
 
@@ -406,13 +404,13 @@ class RabbitMQ:
                 self.rmq_channel.start_consuming()
 
             except ConnectionClosedByBroker:
-                logger.warning("Connection closed by broker, reconnecting...")
+                self.logger.warning("Connection closed by broker, reconnecting...")
                 time.sleep(1)
             except AMQPChannelError as e:
-                logger.error(f"Channel error: {e}")
+                self.logger.error(f"Channel error: {e}")
                 time.sleep(1)
             except Exception as e:
-                logger.error(f"Unexpected error: {e}")
+                self.logger.error(f"Unexpected error: {e}")
                 time.sleep(1)
                 self._setup_connection()
 
@@ -424,13 +422,13 @@ class RabbitMQ:
         """Close connection"""
         if self.rmq_conn and not self.rmq_conn.is_closed:
             try:
-                logger.info("Service RabbitMQ shutdown signal, connection closing...")
+                self.logger.info("Service RabbitMQ shutdown signal, connection closing...")
                 self.rmq_conn.close()
-                logger.info("Connection closed")
+                self.logger.info("Connection closed")
             except Exception as e:
-                logger.error(f"Error closing connection: {e}")
+                self.logger.error(f"Error closing connection: {e}")
         else:
-            logger.info("RabbitMQ already cleaned, no active connection")
+            self.logger.info("RabbitMQ already cleaned, no active connection")
 
     def is_healthy(self):
         """
@@ -442,7 +440,7 @@ class RabbitMQ:
         """Destructor called by garbage collector to ensure resources are cleaned up, when object is about to be destroyed"""
         try:
             if self.is_healthy():
-                logger.error(
+                self.logger.error(
                     "Destructor called by garbage collector to cleanup RabbitMQ"
                 )
                 self.close()
