@@ -19,16 +19,15 @@ from vyomcloudbridge.utils.logger_setup import setup_logger
 from vyomcloudbridge.constants.constants import main_data_queue
 
 
-logger = setup_logger(name=__name__, show_terminal=False)
-
-
 class ThreadedRabbitMQ:  # Note in use
     def __init__(
         self,
         host: str = "localhost",
         queue_name: str = main_data_queue,
         num_threads: int = 10,
+        log_level=None,
     ):
+        self.logger = setup_logger(name=__name__, show_terminal=False, log_level=log_level)
         self.host = host
         self.queue_name = queue_name
         self.num_threads = num_threads
@@ -55,9 +54,9 @@ class ThreadedRabbitMQ:  # Note in use
                 headers = properties.headers
             else:
                 channel.basic_ack(delivery_tag=method_frame.delivery_tag)
-                logger.error(f"Headers not found in messase skipping message")
+                self.logger.error(f"Headers not found in messase skipping message")
                 return
-            logger.debug(f"proccessing data having header={headers}")
+            self.logger.debug(f"proccessing data having header={headers}")
             queue_name = method_frame.routing_key
             priority = properties.priority if properties.priority is not None else 0
             new_priority = max(priority - 1, 0) if priority < 3 else priority  # TODO
@@ -65,7 +64,7 @@ class ThreadedRabbitMQ:  # Note in use
             expiry_info = ""
             if hasattr(properties, "expiration") and properties.expiration:
                 expiry_info = f" with expiration {properties.expiration}ms"
-            logger.debug(
+            self.logger.debug(
                 f"Processing message from {queue_name} with priority {priority}{expiry_info}"
             )
             # pass data to callback in format
@@ -83,10 +82,10 @@ class ThreadedRabbitMQ:  # Note in use
 
             if result:
                 channel.basic_ack(delivery_tag=method_frame.delivery_tag)
-                logger.debug(f"Message processed successfully in {queue_name}")
+                self.logger.debug(f"Message processed successfully in {queue_name}")
             else:
                 # If processing failed, republish with mew priority instead of just nacking
-                logger.warning(
+                self.logger.warning(
                     f"Message processing failed in {queue_name}, requeuing with new priority {new_priority}"
                 )
                 # First ack the original message
@@ -107,7 +106,7 @@ class ThreadedRabbitMQ:  # Note in use
                     else:
                         # new_properties["expiration"] = "0"
                         # Above does not worked, as immediate consumer is available,
-                        logger.info(
+                        self.logger.info(
                             f"Message expiration time reached, marked as expired {queue_name}"
                         )
                         return
@@ -132,11 +131,11 @@ class ThreadedRabbitMQ:  # Note in use
                 )
 
         except Exception as e:
-            logger.error(f"Error processing message in {queue_name}: {e}")
+            self.logger.error(f"Error processing message in {queue_name}: {e}")
             # For exceptions, also republish with new priority
             try:
                 priority = properties.priority if properties.priority is not None else 0
-                logger.warning(
+                self.logger.warning(
                     f"Error processing message, requeuing with new priority {new_priority}"
                 )
                 # First ack the original message
@@ -157,7 +156,7 @@ class ThreadedRabbitMQ:  # Note in use
                     else:
                         # new_properties["expiration"] = "0"
                         # Above does not worked, as immediate consumer is available,
-                        logger.info(
+                        self.logger.info(
                             f"Message expiration time reached, marked as expired {queue_name}"
                         )
                         return
@@ -181,7 +180,7 @@ class ThreadedRabbitMQ:  # Note in use
                     properties=pika.BasicProperties(**new_properties),
                 )
             except Exception as republish_error:
-                logger.error(
+                self.logger.error(
                     f"Failed to republish message with new priority: {republish_error}"
                 )
                 channel.basic_nack(delivery_tag=method_frame.delivery_tag, requeue=True)
@@ -224,15 +223,15 @@ class ThreadedRabbitMQ:  # Note in use
                 on_message_callback=callback_wrapper,
                 auto_ack=False,  # We'll handle acknowledgments manually
             )
-            logger.info(f"Worker thread started for {self.queue_name}")
+            self.logger.info(f"Worker thread started for {self.queue_name}")
             while self.is_consuming:
                 # Process messages for a short time before checking if we should stop
                 rmq_conn.process_data_events(time_limit=1.0)
 
         except (ConnectionClosedByBroker, AMQPChannelError) as e:
-            logger.error(f"Connection error in worker: {e}")
+            self.logger.error(f"Connection error in worker: {e}")
         except Exception as e:
-            logger.error(f"Unexpected error in worker: {e}")
+            self.logger.error(f"Unexpected error in worker: {e}")
         finally:
             if rmq_channel is not None and rmq_channel.is_open:
                 try:
@@ -252,7 +251,7 @@ class ThreadedRabbitMQ:  # Note in use
         Args:
             callback: Function to process messages (should return True for success, False for failure)
         """
-        logger.info(
+        self.logger.info(
             f"Starting consumption from {self.queue_name} with {self.num_threads} threads"
         )
         self.is_consuming = True
@@ -265,7 +264,7 @@ class ThreadedRabbitMQ:  # Note in use
 
             # Setup signal handler for graceful shutdown
             def signal_handler(signum, frame):
-                logger.info("Shutdown signal received, stopping workers...")
+                self.logger.info("Shutdown signal received, stopping workers...")
                 self.is_consuming = False
 
             signal.signal(signal.SIGINT, signal_handler)
@@ -276,7 +275,7 @@ class ThreadedRabbitMQ:  # Note in use
                 for future in futures:
                     future.result()
             except KeyboardInterrupt:
-                logger.info("Keyboard interrupt received, initiating shutdown...")
+                self.logger.info("Keyboard interrupt received, initiating shutdown...")
                 self.is_consuming = False
 
     def stop_consume(self) -> None:  # Note in use
@@ -300,7 +299,7 @@ class ThreadedRabbitMQ:  # Note in use
     def __del__(self):
         """Destructor called by garbage collector to ensure resources are cleaned up, when object is about to be destroyed"""
         try:
-            logger.error(
+            self.logger.error(
                 "Destructor called by garbage collector to cleanup ThreadedRabbitMQ"
             )
             self.close()
