@@ -10,8 +10,6 @@ from vyomcloudbridge.utils.configs import Configs
 from vyomcloudbridge.utils.logger_setup import setup_logger
 from vyomcloudbridge.constants.constants import RESERVED_KEYS, DEFAULT_RABBITMQ_URL
 
-logger = setup_logger(name=__name__, show_terminal=False)
-
 
 class RootStore(ServiceAbstract):  # Not in use
     """
@@ -19,11 +17,11 @@ class RootStore(ServiceAbstract):  # Not in use
     Each key has its own queue in RabbitMQ that stores the latest state of its data.
     """
 
-    def __init__(self):
+    def __init__(self, log_level=None):
         """
         Initialize the generic data service with RabbitMQ connection.
         """
-        super().__init__()
+        super().__init__(log_level=log_level)
         self.host: str = "localhost"
         self.rabbitmq_url = DEFAULT_RABBITMQ_URL
         self.publish_interval = 5
@@ -45,7 +43,7 @@ class RootStore(ServiceAbstract):  # Not in use
                 exchange="general_store_exchange", exchange_type="direct", durable=True
             )
 
-            self.logger.debug("RabbitMQ connection established successfully")
+            self.logger.info("RabbitMQ connection established successfully")
         except Exception as e:
             self.logger.error(f"Failed to initialize RabbitMQ: {str(e)}")
             raise
@@ -58,14 +56,14 @@ class RootStore(ServiceAbstract):  # Not in use
                 return True
 
             if not self.rmq_channel or self.rmq_channel.is_closed:
-                logger.info("Closed channel found, re-establishing...")
+                self.logger.info("Closed channel found, re-establishing...")
                 self.rmq_channel = self.rmq_conn.channel()
                 self.rmq_channel.exchange_declare(
                     exchange="general_store_exchange",
                     exchange_type="direct",
                     durable=True,
                 )
-                logger.info("Channel re-established successfully")
+                self.logger.info("Channel re-established successfully")
 
             return True
         except Exception as e:
@@ -380,6 +378,9 @@ class RootStore(ServiceAbstract):  # Not in use
             pass
 
 
+logger = setup_logger(name=__name__, show_terminal=False, log_level=logging.INFO)
+
+
 def _get_machine_id() -> str:
     """Get the machine ID from config or return a default value."""
     try:
