@@ -60,7 +60,14 @@ class SendDataToServer(Node, ServiceAbstract):
         create_dynamic_subscribers(f_topic): Dynamically creates a subscriber for a given topic.
     """
 
-    def __init__(self, get_current_mission: Callable = None, start_mission: Callable = None, end_current_mission: Callable = None, generate_mission_id: Callable = None):
+    def __init__(
+        self,
+        get_current_mission: Callable = None,
+        start_mission: Callable = None,
+        end_current_mission: Callable = None,
+        generate_mission_id: Callable = None,
+        log_level=None,
+    ):
         Node.__init__(self, "senddatatoserver")
         ServiceAbstract.__init__(self)
 
@@ -84,7 +91,7 @@ class SendDataToServer(Node, ServiceAbstract):
             durability=QoSDurabilityPolicy.VOLATILE,
         )
 
-        self.writer = QueueWriterJson()
+        self.writer = QueueWriterJson(log_level=log_level)
 
         self.mission_id = default_mission_id
         self.is_running = False
@@ -97,7 +104,7 @@ class SendDataToServer(Node, ServiceAbstract):
         self.generate_mission_id = generate_mission_id
         self.update_mission_thread = None
 
-        self.summariser = Summariser()
+        self.summariser = Summariser(log_level=log_level)
 
         # ros topic used to trigger updation of subscriber list
         self.topic_list_sub = self.create_subscription(
@@ -119,7 +126,9 @@ class SendDataToServer(Node, ServiceAbstract):
 
             if current_mission_message is not None:
                 current_mission_id = current_mission_message.get("id")
-                self.logger.debug(f"Mission already in progress. Current mission: {current_mission_message}")
+                self.logger.debug(
+                    f"Mission already in progress. Current mission: {current_mission_message}"
+                )
                 return
 
             new_id = self.generate_mission_id()
@@ -152,10 +161,19 @@ class SendDataToServer(Node, ServiceAbstract):
             else:
                 self.logger.info("Current mission ended successfully.")
         except Exception as e:
-            self.logger.error(f"An error occurred while ending current mission: {str(e)}")
-        
-        
-    def send_data(self, f_extracted_data, f_filename, f_topic_name, f_data_type, f_destination, f_send_persistent):
+            self.logger.error(
+                f"An error occurred while ending current mission: {str(e)}"
+            )
+
+    def send_data(
+        self,
+        f_extracted_data,
+        f_filename,
+        f_topic_name,
+        f_data_type,
+        f_destination,
+        f_send_persistent,
+    ):
         success, error = self.writer.write_message(
             message_data=f_extracted_data,  # json data
             filename=f_filename,  # nullable or epoch time
@@ -295,7 +313,7 @@ class SendDataToServer(Node, ServiceAbstract):
         self.update_mission_thread.start()
 
         mission_triggers = self.get_mission_triggers()
-        if (len(mission_triggers) > 0):
+        if len(mission_triggers) > 0:
             self.mission_triggers = mission_triggers
             self.logger.info(f"Mission triggers: {self.mission_triggers}")
         else:
@@ -346,8 +364,10 @@ class SendDataToServer(Node, ServiceAbstract):
 
         topic_list = self.load_topic_list_from_file()
         return [
-            topics for topics in topic_list
-            if topics.get("is_subscribed", False) or topics.get("is_subscribe_on_mission", False)
+            topics
+            for topics in topic_list
+            if topics.get("is_subscribed", False)
+            or topics.get("is_subscribe_on_mission", False)
         ]
 
     def load_topic_list_from_file(self):
@@ -525,11 +545,11 @@ class SendDataToServer(Node, ServiceAbstract):
 
                 os.makedirs(local_path, exist_ok=True)
                 full_path = os.path.join(local_path, filename)
-                
+
                 with open(full_path, "wb") as image_file:
                     image_file.write(extracted_data)
                 self.logger.debug(f"Image saved locally at: {full_path}")
-                
+
             else:
                 with open(local_path, "a") as file:
                     json.dump(extracted_data, file)
@@ -539,11 +559,25 @@ class SendDataToServer(Node, ServiceAbstract):
             self.logger.debug(f"Sending data for: {f_topic_name}")
             if f_can_send_buffered:
                 self.logger.debug(f"Buffered sending enabled for: {f_topic_name}")
-                self.send_data(extracted_data, filename, f_topic_name, data_type, f_destination, True)
+                self.send_data(
+                    extracted_data,
+                    filename,
+                    f_topic_name,
+                    data_type,
+                    f_destination,
+                    True,
+                )
 
             if f_can_send_live:
                 self.logger.debug(f"Live sending enabled for: {f_topic_name}")
-                self.send_data(extracted_data, filename, f_topic_name, data_type, f_destination, False)
+                self.send_data(
+                    extracted_data,
+                    filename,
+                    f_topic_name,
+                    data_type,
+                    f_destination,
+                    False,
+                )
 
         else:
             self.logger.warning(f"Cannot send or save data for: {f_topic_name}")
@@ -568,11 +602,15 @@ class SendDataToServer(Node, ServiceAbstract):
 
                 if str(expected_value) == str(actual_value):
                     if trigger_type == "start_mission_trigger":
-                        self.logger.info(f"Start mission triggered by {field}={actual_value}")
+                        self.logger.info(
+                            f"Start mission triggered by {field}={actual_value}"
+                        )
                         self.initiate_mission()
                         return True
                     elif trigger_type == "stop_mission_trigger":
-                        self.logger.info(f"Stop mission triggered by {field}={actual_value}")
+                        self.logger.info(
+                            f"Stop mission triggered by {field}={actual_value}"
+                        )
                         self.terminate_mission()
                         return False
 
@@ -601,7 +639,9 @@ class SendDataToServer(Node, ServiceAbstract):
 
             if len(self.mission_triggers) > 0:
                 if f_topic not in self.mission_triggers:
-                    self.logger.debug(f"No mission triggers defined for topic {f_topic}")
+                    self.logger.debug(
+                        f"No mission triggers defined for topic {f_topic}"
+                    )
                 else:
                     if self.mission_trigger_action(msg, f_topic):
                         self.logger.debug("Start mission triggered")
@@ -618,15 +658,23 @@ class SendDataToServer(Node, ServiceAbstract):
                 self.summariser.update(f_topic, msg)
 
             if f_is_subscribed:
-                self.logger.debug(f"Processing and sending data for topic: {f_topic_name}")
+                self.logger.debug(
+                    f"Processing and sending data for topic: {f_topic_name}"
+                )
             else:
                 self.logger.info(f"Checking if is_subscribe_on_mission")
-                self.logger.info(f"self.current_mission.get('mission_status'): {l_current_mission}")
+                self.logger.info(
+                    f"self.current_mission.get('mission_status'): {l_current_mission}"
+                )
 
                 if f_is_subscribe_on_mission and l_current_mission == 1:
-                    self.logger.info(f"Processing and sending data for topic: {f_topic_name} during mission")
+                    self.logger.info(
+                        f"Processing and sending data for topic: {f_topic_name} during mission"
+                    )
                 else:
-                    self.logger.info(f"Not processing data for topic: {f_topic_name} as not subscribed and not during mission")
+                    self.logger.info(
+                        f"Not processing data for topic: {f_topic_name} as not subscribed and not during mission"
+                    )
                     return callback
 
             self.logger.debug(f"Ros data processing for ros_topic: {f_topic_name}")
@@ -783,12 +831,12 @@ class SendDataToServer(Node, ServiceAbstract):
 
 
 class RosPublisher(ServiceAbstract):
-    def __init__(self):
-        super().__init__()
+    def __init__(self, log_level=None):
+        super().__init__(log_level=log_level)
         self.logger.info("Initializing RosPublisher..")
         self.is_running = False
         self.spin_thread = None
-        self.mission_utils = MissionUtils()
+        self.mission_utils = MissionUtils(log_level=log_level)
         self.get_current_mission = self.mission_utils.get_current_mission
         self.start_mission = self.mission_utils.start_mission
         self.end_current_mission = self.mission_utils.end_current_mission
@@ -799,7 +847,13 @@ class RosPublisher(ServiceAbstract):
         except Exception as e:
             self.logger.warning(f"Failed to initialize ROS: {e}")
 
-        self.send_data_to_server = SendDataToServer(self.get_current_mission, self.start_mission, self.end_current_mission,self.generate_mission_id)
+        self.send_data_to_server = SendDataToServer(
+            self.get_current_mission,
+            self.start_mission,
+            self.end_current_mission,
+            self.generate_mission_id,
+            log_level=self.log_level,
+        )
         self.logger.info("RosPublisher Initialized successfully")
 
     def start(self):
@@ -863,4 +917,4 @@ def main(args=None):
 
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
