@@ -27,8 +27,6 @@ from vyomcloudbridge.utils.common import (
 from vyomcloudbridge.constants.constants import data_buffer_key
 import traceback
 
-# logger = setup_logger(name=__name__, show_terminal=False)
-
 
 class StreamConsumer:
     def __init__(
@@ -39,6 +37,7 @@ class StreamConsumer:
         # low priority
         priority: int = 1,
         preserve_file: bool = False,  # this we will implement later, move it to <dir>_preserve
+        log_level=None,
     ):
         """
         Initialize the StreamConsumer with the specified watch directory.
@@ -48,9 +47,11 @@ class StreamConsumer:
         """
 
         try:
+            self.log_level = log_level
             self.logger = setup_logger(
                 name=self.__class__.__module__ + "." + self.__class__.__name__,
                 show_terminal=False,
+                log_level=log_level,
             )
 
             self.watch_dir = Path(stream_dir)
@@ -421,7 +422,9 @@ class StreamConsumer:
             try:
                 self.logger.info("Initializing StreamFormatter client...")
                 self.queue_writer_client = StreamFormatter(
-                    multi_machine=self.multi_machine, machine_key=self.machine_key
+                    multi_machine=self.multi_machine,
+                    machine_key=self.machine_key,
+                    log_level=self.log_level,
                 )
                 self.is_running = True
                 self.logger.info("StreamFormatter client initialized successfully")
