@@ -26,19 +26,22 @@ from vyomcloudbridge.constants.constants import (
 )
 
 
-# logger = setup_logger(name=__name__, show_terminal=False)
-
-
 class StreamFormatter:
     """Main class for handling message queue writing operations."""
 
     # Mapping file extensions to data types
-    def __init__(self, multi_machine: bool = False, machine_key: Optional[str] = None):
+    def __init__(
+        self,
+        multi_machine: bool = False,
+        machine_key: Optional[str] = None,
+        log_level=None,
+    ):
         self.logger = setup_logger(
             name=self.__class__.__module__ + "." + self.__class__.__name__,
             show_terminal=False,
+            log_level=log_level,
         )
-        self.rabbit_mq = RabbitMQ()
+        self.rabbit_mq = RabbitMQ(log_level=log_level)
         self.machine_config = Configs.get_machine_config()
         self.machine_id = self.machine_config.get("machine_id", "-") or "-"
         self.organization_id = self.machine_config.get("organization_id", "-") or "-"
