@@ -23,6 +23,7 @@ class VyomSender:
 
     def __init__(
         self,
+        log_level=None,
     ):
         try:
             """Initialize the Vyom Sender client"""
@@ -31,17 +32,18 @@ class VyomSender:
             self.logger = setup_logger(
                 name=self.__class__.__module__ + "." + self.__class__.__name__,
                 show_terminal=False,
+                log_level=log_level,
             )
             self.logger.info("Starting VyomSender...")
             self.install_specs = InstallSpecs()
             self.machine_config = Configs.get_machine_config()
             self.machine_id = self.machine_config.get("machine_id", "-") or "-"
             self.logger.info("Setting up all senders...")
-            self.senders = {"mqtt": AwsiotMqttSender(daemon=True)}
+            self.senders = {"mqtt": AwsiotMqttSender(daemon=True, log_level=log_level)}
             if self.install_specs.is_full_install:
                 from vyomcloudbridge.senders.mav_sender import MavSender
 
-                self.senders["mavlink"] = (MavSender(),)
+                self.senders["mavlink"] = MavSender(log_level=log_level)
             self.logger.info("Setup of all senders Done!")
             # TODO, need to handle gcs_mav, machine,
             self.network = self._load_network_config()
@@ -153,7 +155,6 @@ class VyomSender:
 
 
 # Initialize the singleton instance
-# vyom_sender = VyomSender()
 
 
 def main():
