@@ -32,6 +32,7 @@ from vyomcloudbridge.constants.constants import (
     root_ca_file_path,
     vyom_variables_file,
     default_machine_type,
+    DEFAULT_TIMEZONE,
     MACHINE_REGISTER_API_URL,
     MACHINE_MODELS_API_URL,
     MACHINE_TOPICS_API_URL,
@@ -435,6 +436,66 @@ def register_machine(interactive=True):
     machine_uid = input("Machine UID: ").strip()
     machine_name = input("Machine Name: ").strip()
 
+    # Timezone selection
+    timezone = DEFAULT_TIMEZONE
+    timezone_choices = {
+        1: "UTC",
+        2: "Asia/Kolkata",
+        3: "America/New_York",
+        4: "America/Los_Angeles",
+        5: "Europe/London",
+        6: "Europe/Paris",
+        7: "Asia/Tokyo",
+        8: "Asia/Shanghai",
+        9: "Australia/Sydney",
+    }
+
+    print(
+        f'\nDevice Timezone: {timezone}, type "y" if you want to change it [Y/n]: ',
+        end="",
+    )
+    change_timezone = input().strip().lower()
+
+    if change_timezone == "y":
+        print("\nChoices:")
+        print("1 - UTC")
+        print("2 - Asia/Kolkata (IST)")
+        print("3 - America/New_York (EST/EDT)")
+        print("4 - America/Los_Angeles (PST/PDT)")
+        print("5 - Europe/London (GMT/BST)")
+        print("6 - Europe/Paris (CET/CEST)")
+        print("7 - Asia/Tokyo (JST)")
+        print("8 - Asia/Shanghai (CST)")
+        print("9 - Australia/Sydney (AEST/AEDT)")
+
+        max_attempts = 3
+        for attempt in range(max_attempts):
+            try:
+                choice_input = input(
+                    "Type integer value corresponding to correct timezone, and enter: "
+                ).strip()
+                choice = int(choice_input)
+                if choice in timezone_choices:
+                    timezone = timezone_choices[choice]
+                    print(f"Timezone set to: {timezone}")
+                    break
+                else:
+                    remaining = max_attempts - attempt - 1
+                    if remaining > 0:
+                        print(
+                            f"Invalid choice. Please enter a number between 1 and 9. ({remaining} attempts remaining)"
+                        )
+                    else:
+                        print(f"Invalid choice. Using default timezone: {timezone}")
+            except ValueError:
+                remaining = max_attempts - attempt - 1
+                if remaining > 0:
+                    print(
+                        f"Invalid input. Please enter a valid integer. ({remaining} attempts remaining)"
+                    )
+                else:
+                    print(f"Invalid input. Using default timezone: {timezone}")
+
     ssh_enabled = False
     ssh_confirm = (
         input("Do you want to set up remote SSH, routed via VyomIQ domain? [Y/n]: ")
@@ -476,6 +537,7 @@ def register_machine(interactive=True):
         "machine_uid": machine_uid,
         "name": machine_name,
         "ssh_enabled": ssh_enabled,
+        "timezone": timezone,
         # machine topic detail
         "machine_model_topics": machine_model_topics,
     }
@@ -534,6 +596,7 @@ def register_machine(interactive=True):
                         "ssh_port": str(data["data"].get("ssh_port", "")),
                         "ssh_enabled": str(data["data"].get("ssh_enabled", "")),
                         "ssh_key": data["data"].get("ssh_key", ""),
+                        "timezone": data["data"].get("timezone", ""),
                         "created_at": data["data"].get("created_at", ""),
                         "updated_at": data["data"].get("updated_at", ""),
                         "session_id": data["data"].get("session_id", ""),
@@ -936,10 +999,12 @@ def setup_service():
                 try:
                     service_username = saved_data.get("service_username")
                 except Exception as e:
-                    print(f"Error reading vyom_variables_file= {vyom_variables_file}: {str(e)}")  
-                
+                    print(
+                        f"Error reading vyom_variables_file= {vyom_variables_file}: {str(e)}"
+                    )
+
                 if not service_username:
-                    service_username = saved_data.get("ros_username") # TODO 
+                    service_username = saved_data.get("ros_username")  # TODO
         except Exception as e:
             print(f"Error reading vyom_variables_file= {vyom_variables_file}: {str(e)}")
             vyom_env_file = None  # ensure fallback to prompting
@@ -1030,7 +1095,7 @@ def setup_service():
 
     if not service_username and install_specs.is_lite_install:
         service_username = "root"
-    
+
     if not service_username:
         MAX_USERNAME_ATTEMPTS = 3
         for attempt in range(MAX_USERNAME_ATTEMPTS):
@@ -1183,7 +1248,9 @@ WantedBy=multi-user.target
     # TODO remove later
     if ssh_enabled and ssh_port:
         if ssh_key:
-            ssh_success, ssh_error = setup_ssh_service(ssh_key, ssh_port, service_username)
+            ssh_success, ssh_error = setup_ssh_service(
+                ssh_key, ssh_port, service_username
+            )
             if not ssh_success:
                 return False, ssh_error
         else:
