@@ -2,6 +2,7 @@ import abc
 from datetime import datetime, timezone
 import signal
 import sys
+import logging
 import time
 from typing import Dict, Any, List, Tuple, Union
 from vyomcloudbridge.constants.constants import SERVICE_ID
@@ -47,12 +48,13 @@ class ServiceAbstract(abc.ABC):
     All service implementations should inherit from this class.
     """
 
-    def __init__(self, multi_thread: bool = False):
+    def __init__(self, multi_thread: bool = False, log_level=None):
         self.is_running = False
         self.multi_thread = multi_thread
         self.logger = setup_logger(
             name=self.__class__.__module__ + "." + self.__class__.__name__,
             show_terminal=False,
+            log_level=log_level,
         )
         self._setup_signal_handlers()
 
