@@ -34,5 +34,11 @@
         "name": "systemcheck",
         "data_type": "vyom_msg.msg.Systemcheck",
         "topic": "systemcheck"
+    },
+    {
+        "id": 388,
+        "name": "e2e_diagnosis",
+        "data_type": "std_msgs.msg.String",
+        "topic": "e2e_diagnosis"
     }
 ]
