@@ -4,13 +4,38 @@ import signal
 import sys
 from typing import Dict, Any
 import json
+from zoneinfo import ZoneInfo
 from vyomcloudbridge.utils.logger_setup import setup_logger
-from vyomcloudbridge.constants.constants import machine_config_file
+from vyomcloudbridge.constants.constants import DEFAULT_TIMEZONE, machine_config_file
 
 logger = setup_logger(name=__name__, show_terminal=False)
 
 
 class Configs:
+    @staticmethod
+    def _validate_timezone(timezone_str: str) -> str:
+        """
+        Validate timezone string and return DEFAULT_TIMEZONE if invalid.
+
+        Args:
+            timezone_str: Timezone string to validate
+
+        Returns:
+            Valid timezone string or DEFAULT_TIMEZONE as fallback
+        """
+        if not timezone_str:
+            return DEFAULT_TIMEZONE
+
+        try:
+            # Test if the timezone is valid by creating a ZoneInfo object
+            ZoneInfo(timezone_str)
+            return timezone_str
+        except Exception as e:
+            logger.warning(
+                f"Invalid timezone '{timezone_str}', falling back to default: {e}"
+            )
+            return DEFAULT_TIMEZONE
+
     @staticmethod
     def get_machine_config() -> Dict[str, Any]:
         config = configparser.ConfigParser()
@@ -152,6 +177,23 @@ class Configs:
             except Exception as e:
                 machine_detail["mqtt_primary_channel"] = ["awsiot"]
 
+            # Timezone support - validate timezone and fallback to default if invalid
+            try:
+                timezone = config["MACHINE"]["timezone"]
+                machine_detail["timezone"] = Configs._validate_timezone(timezone)
+            except (KeyError, ValueError):
+                machine_detail["timezone"] = DEFAULT_TIMEZONE
+                logger.debug(f"Failed to get timezone from {machine_config_file}")
+            except Exception as e:
+                machine_detail["timezone"] = DEFAULT_TIMEZONE
+
+            # from datetime import datetime
+            # from zoneinfo import ZoneInfo # Python 3.9+ buil-in
+
+            # tz_str = "Asia/Kolkata"
+            # now_local = datetime.now(ZoneInfo(tz_str))
+            # print(now_local)
+
             try:
                 destination_ids = config["MACHINE"][
                     "destination_ids"
@@ -188,6 +230,7 @@ class Configs:
                 "ssh_key": "",
                 "access_public_key": "",  # in use
                 "access_private_key": "",  # in use
+                "timezone": DEFAULT_TIMEZONE,
             }
 
 
@@ -206,6 +249,7 @@ def main():
     ssh_key = machine_config.get("ssh_key", "-") or "-"
     access_public_key = machine_config.get("access_public_key", "-") or "-"
     access_private_key = machine_config.get("access_private_key", "-") or "-"
+    timezone = machine_config.get("timezone", "-") or "-"
 
     print("machine_id:", machine_id)
     print("machine_uid:", machine_uid)
@@ -220,6 +264,7 @@ def main():
     print("ssh_key:", ssh_key)
     print("access_public_key:", access_public_key)
     print("access_private_key:", access_private_key)
+    print("timezone:", timezone)
 
 
 if __name__ == "__main__":
