@@ -21,13 +21,14 @@ class Diagnose:
     and measuring upload performance. Uses RabbitMQ for queue management.
     """
 
-    def __init__(self, show_log=False):
+    def __init__(self, show_log=False, log_level=None):
         """
         Initialize the diagnostic service with RabbitMQ connection and configuration.
         """
         self.logger = setup_logger(
             name=self.__class__.__module__ + "." + self.__class__.__name__,
             show_terminal=show_log,
+            log_level=log_level,
         )
         self.priority_data = 1  # Priority for data messages
         self.priority_response = 2  # Priority for response messages
@@ -40,7 +41,7 @@ class Diagnose:
         self.destination_ids = ["s3"]
         self.speed_test_thread = None
         self.speed_test_timeout = 10 * 60 * 1000  # milliseconds, 10 minutes max
-        self.writer = QueueWriterJson()
+        self.writer = QueueWriterJson(log_level=log_level)
 
         # self.file_url = "https://mirror.del.albony.in/videolan-ftp/vlc/3.0.21/macosx/vlc-3.0.21-intel64.dmg"
         # self.file_size = 10  # in MB
@@ -127,7 +128,9 @@ class Diagnose:
         try:
             # Resolve local sample file path in constants directory
             current_dir = os.path.dirname(os.path.abspath(__file__))
-            constants_dir = os.path.normpath(os.path.join(current_dir, "..", "constants"))
+            constants_dir = os.path.normpath(
+                os.path.join(current_dir, "..", "constants")
+            )
             sample_file_path = os.path.join(constants_dir, "sample_image.jpg")
 
             if not os.path.exists(sample_file_path):
@@ -141,7 +144,9 @@ class Diagnose:
             file_extension = os.path.splitext(sample_file_path)[1].lstrip(".") or "bin"
 
             # Compute how many chunks to reach requested size
-            effective_unit_size_mb = file_size_mb_actual if file_size_mb_actual > 0 else self.file_size
+            effective_unit_size_mb = (
+                file_size_mb_actual if file_size_mb_actual > 0 else self.file_size
+            )
             loop_len = int(size / effective_unit_size_mb)
             if size % effective_unit_size_mb:
                 loop_len = loop_len + 1
