@@ -4,16 +4,16 @@ from collections import defaultdict
 from vyomcloudbridge.utils.logger_setup import setup_logger
 
 
-
 class Summariser:
-    def __init__(self, filter_file_path="filter.json"):        
+    def __init__(self, filter_file_path="filter.json", log_level=None):
         self.logger = setup_logger(
             name=self.__class__.__module__ + "." + self.__class__.__name__,
             show_terminal=False,
+            log_level=log_level,
         )
         self.reset()
         self.is_mission = 1
-        
+
     def set_mission_mode(self, is_mission: int):
         """
         Set the mission mode for the summariser.
@@ -27,35 +27,41 @@ class Summariser:
         :return: The current mission mode (0, 1, or 2).
         """
         return self.is_mission
-        
-        
+
     def reset(self):
         """
         Reset the statistics and allowed fields.
         """
-        self.stats = defaultdict(lambda: defaultdict(lambda: {
-            "min": float("inf"),
-            "max": float("-inf"),
-            "sum": 0.0,
-            "count": 0
-        }))
+        self.stats = defaultdict(
+            lambda: defaultdict(
+                lambda: {
+                    "min": float("inf"),
+                    "max": float("-inf"),
+                    "sum": 0.0,
+                    "count": 0,
+                }
+            )
+        )
         self.allowed_fields = {}
         self.load_filter_from_file()
-        
 
     def load_filter_from_file(self):
         """
         Load allowed topic and field filters from a JSON file.
         """
-        abs_path = os.path.abspath(os.path.join(os.path.dirname(__file__), '../utils/filter_data_fields.py'))
+        abs_path = os.path.abspath(
+            os.path.join(os.path.dirname(__file__), "../utils/filter_data_fields.py")
+        )
         self.logger.debug(f"Looking for filter file at: {abs_path}")
         try:
-            with open(abs_path, 'r') as f:
+            with open(abs_path, "r") as f:
                 data = json.load(f)
                 self.allowed_fields = {
                     topic: set(fields) for topic, fields in data.items()
                 }
-                self.logger.debug(f"Loaded filter for topics: {list(self.allowed_fields.keys())}")
+                self.logger.debug(
+                    f"Loaded filter for topics: {list(self.allowed_fields.keys())}"
+                )
         except Exception as e:
             self.logger.debug(f"Failed to load filter JSON: {e}")
             self.allowed_fields = {}
@@ -89,16 +95,20 @@ class Summariser:
         Recursively extract numeric fields from a ROS 2 message.
         """
         fields = {}
-        if hasattr(msg, '__slots__'):
+        if hasattr(msg, "__slots__"):
             for field_name in msg.__slots__:
                 value = getattr(msg, field_name, None)
                 full_key = f"{prefix}.{field_name}" if prefix else field_name
 
                 if isinstance(value, (int, float)):
                     fields[full_key] = value
-                elif hasattr(value, '__slots__'):
+                elif hasattr(value, "__slots__"):
                     fields.update(self.extract_numeric_fields(full_key, value))
-                elif isinstance(value, (list, tuple)) and value and isinstance(value[0], (int, float)):
+                elif (
+                    isinstance(value, (list, tuple))
+                    and value
+                    and isinstance(value[0], (int, float))
+                ):
                     for i, v in enumerate(value):
                         fields[f"{full_key}[{i}]"] = v
         elif isinstance(msg, (int, float)):
@@ -115,13 +125,13 @@ class Summariser:
         for topic, fields in self.stats.items():
             summary[topic] = {}
             for field, stat in fields.items():
-                cleaned_field = field.lstrip('_')  # Remove leading underscore
+                cleaned_field = field.lstrip("_")  # Remove leading underscore
                 avg = stat["sum"] / stat["count"] if stat["count"] > 0 else None
                 summary[topic][cleaned_field] = {
                     "min": stat["min"],
                     "max": stat["max"],
                     "avg": avg,
-                    "count": stat["count"]
+                    "count": stat["count"],
                 }
         return summary
 
@@ -130,11 +140,13 @@ class Summariser:
         Optionally logs or prints the summary to console or via a ROS 2 logger.
         """
         summary = self.generate_summary()
-        
+
         self.logger.info(f"Summary details: {summary}")
 
         if not summary or all(not fields for fields in summary.values()):
-            self.logger.debug("📭 No summary data available. No matching updates received.")
+            self.logger.debug(
+                "📭 No summary data available. No matching updates received."
+            )
             return
 
         for topic, fields in summary.items():
@@ -160,5 +172,5 @@ class Summariser:
                     logger.info(line)
                 else:
                     self.logger.debug(line)
-                    
+
         return summary
