@@ -23,7 +23,7 @@ class MissionUtils:
     Also maintains current mission and current user data in dedicated queues.
     """
 
-    def __init__(self):
+    def __init__(self, log_level=None):
         """
         Initialize the mission data service with RabbitMQ connection.
 
@@ -35,6 +35,7 @@ class MissionUtils:
             self.logger = setup_logger(
                 name=self.__class__.__module__ + "." + self.__class__.__name__,
                 show_terminal=False,
+                log_level=log_level,
             )
             self.host: str = "localhost"
             self.rabbitmq_url = DEFAULT_RABBITMQ_URL
@@ -44,7 +45,7 @@ class MissionUtils:
 
             self.rmq_conn = None
             self.rmq_channel = None
-            self.rabbit_mq = RabbitMQ()
+            self.rabbit_mq = RabbitMQ(log_level=log_level)
             self.machine_config = Configs.get_machine_config()
             self.machine_id = self.machine_config.get("machine_id", "-") or "-"
             self.organization_id = (
